import * as i3 from '@angular/common';
import { CommonModule } from '@angular/common';
import * as i0 from '@angular/core';
import { EventEmitter, Directive, Output, HostListener, Pipe, Component, ViewChild, Input, NgModule, Injectable } from '@angular/core';
import * as i4 from 'ngx-image-cropper';
import { base64ToFile, ImageCropperComponent, ImageCropperModule } from 'ngx-image-cropper';
import * as i1 from '@angular/fire/compat/storage';
import * as i2 from '@angular/platform-browser';

class DropZoneDirective {
    constructor() {
        this.dropped = new EventEmitter();
        this.hovered = new EventEmitter();
    }
    onDrop($event) {
        $event.preventDefault();
        this.dropped.emit($event.dataTransfer.files);
        this.hovered.emit(false);
    }
    onDragOver($event) {
        $event.preventDefault();
        this.hovered.emit(true);
    }
    onDragLeave($event) {
        $event.preventDefault();
        this.hovered.emit(false);
    }
    onClick($event) {
        // $event.preventDefault();
        document.getElementById('file-input').click();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.1.2", ngImport: i0, type: DropZoneDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "17.1.2", type: DropZoneDirective, selector: "[dropZone]", outputs: { dropped: "dropped", hovered: "hovered" }, host: { listeners: { "drop": "onDrop($event)", "dragover": "onDragOver($event)", "dragleave": "onDragLeave($event)", "click": "onClick($event)" } }, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.1.2", ngImport: i0, type: DropZoneDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[dropZone]'
                }]
        }], ctorParameters: () => [], propDecorators: { dropped: [{
                type: Output
            }], hovered: [{
                type: Output
            }], onDrop: [{
                type: HostListener,
                args: ['drop', ['$event']]
            }], onDragOver: [{
                type: HostListener,
                args: ['dragover', ['$event']]
            }], onDragLeave: [{
                type: HostListener,
                args: ['dragleave', ['$event']]
            }], onClick: [{
                type: HostListener,
                args: ['click', ['$event']]
            }] } });

class DropZoneText {
    constructor(lang) {
        this.title = 'File Drop Zone';
        this.subtitle = 'Drop your file here';
        this.action = {
            or: 'or',
            click: 'click here',
            choose: 'to choose a file...',
            rotateLeft: 'Rotate left',
            rotateRight: 'Rotate right',
            flipHorizontal: 'Flip horizontal',
            flipVertical: 'Flip Vertical',
            zoomIn: 'Zoom +',
            zoomOut: 'Zoom -',
            reset: 'Reset image',
        };
        this.button = {
            pause: 'Pause',
            cancel: 'Cancel',
            resume: 'Resume',
            upload: 'Upload File',
            change: 'Change File'
        };
        this.errors = {
            type: 'Unsupported file type. ',
            size: 'The file is too heavy. ',
        };
        switch (lang) {
            case 'es':
                this.title = 'Área de carga';
                this.subtitle = 'Arrastre el archivo aquí',
                    this.action = {
                        or: 'ó',
                        click: 'Haga click aquí',
                        choose: 'para escoger su archivo...',
                        rotateLeft: 'Rotar Izq',
                        rotateRight: 'Rotar Der',
                        flipHorizontal: 'Girar horizontal',
                        flipVertical: 'Girar Vertical',
                        zoomIn: 'Acercar',
                        zoomOut: 'Alejar',
                        reset: 'Resetear',
                    };
                this.button = {
                    pause: 'Pausa',
                    cancel: 'Cancelar',
                    resume: 'Continuar',
                    upload: 'Cargar archivo',
                    change: 'Cambiar archivo'
                };
                this.errors = {
                    type: 'El tipo de archivo no es permitido.',
                    size: 'El archivo es muy grande. ',
                };
                break;
            default:
                break;
        }
    }
}

const FILE_SIZE_UNITS = ['B', 'KB', 'MB', 'GB', 'TB', 'PB', 'EB', 'ZB', 'YB'];
const FILE_SIZE_UNITS_LONG = ['Bytes', 'Kilobytes', 'Megabytes', 'Gigabytes', 'Pettabytes', 'Exabytes', 'Zettabytes', 'Yottabytes'];
class FileSizePipe {
    transform(sizeInBytes, longForm) {
        const units = longForm
            ? FILE_SIZE_UNITS_LONG
            : FILE_SIZE_UNITS;
        let power = Math.round(Math.log(sizeInBytes) / Math.log(1024));
        power = Math.min(power, units.length - 1);
        const size = sizeInBytes / Math.pow(1024, power); // size in new units
        const formattedSize = Math.round(size * 100) / 100; // keep up to 2 decimals
        const unit = units[power];
        return size ? `${formattedSize} ${unit}` : '0';
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.1.2", ngImport: i0, type: FileSizePipe, deps: [], target: i0.ɵɵFactoryTarget.Pipe }); }
    static { this.ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "14.0.0", version: "17.1.2", ngImport: i0, type: FileSizePipe, name: "fileSize" }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.1.2", ngImport: i0, type: FileSizePipe, decorators: [{
            type: Pipe,
            args: [{
                    name: 'fileSize'
                }]
        }] });

class NgxImageHandlerComponent {
    constructor(storage, sanitizer) {
        this.storage = storage;
        this.sanitizer = sanitizer;
        this.res = new EventEmitter();
        this.lang = 'en';
        this.cropper = false;
        this.cropperConfig = {
            aspectRatio: 1 / 1,
            maintainAspectRatio: true,
            containWithinAspectRatio: false,
            cropperMinHeight: 0,
            cropperMinWidth: 0,
            resizeToWidth: 0,
            resizeToHeight: 0,
            cropperStaticWidth: 0,
            cropperStaticHeight: 0,
        };
        this.error = {
            type: false,
            size: false
        };
        // Cropped
        this.croppedImage = '';
        this.croppedImageConfig = {
            rotation: 0,
            canvasRotation: 0,
            showCropper: false,
            scale: 1,
            transform: {},
        };
        // State for dropzone CSS toggling
        this.isHovering = false;
        this.ImageType = false;
    }
    toggleHover(event) {
        this.isHovering = !!event;
    }
    loadTempFile(event) {
        this.error.type = false;
        this.error.size = false;
        this.ImageType = true;
        const file = event.target ? event.target.files.item(0) : event.item(0);
        // Client-side validation example
        if (this.onlyType) {
            let allow = false;
            allow = this.onlyType.split(',').some(type => file.type.includes(type.trim()));
            if (!allow) {
                this.error.type = true;
                console.error('unsupported file type: ', file.type);
                return;
            }
        }
        if (this.maxSize && (file.size / (1024 * 1024)) >= this.maxSize) {
            this.error.size = true;
            console.error('unsupported size file. Its too heavy ', file.size);
            return;
        }
        if (!this.error.type && !this.error.size) {
            if (event.target) {
                this.tempFile = event;
            }
            else {
                let aux = {
                    target: {
                        files: new Array()
                    }
                };
                aux.target.files.push(file);
                this.tempFile = aux;
            }
            if (file.type.includes('image')) {
                this.imageLoaded();
            }
            else {
                this.ImageType = false;
            }
        }
    }
    changeImage() {
        this.tempFile = null;
    }
    // startUpload(event: FileList) {
    startUpload(event) {
        let file;
        if (!this.cropper && this.tempFile) {
            file = this.tempFile.target ? this.tempFile.target.files[0] : this.tempFile;
        }
        else {
            file = base64ToFile(this.croppedImage);
        }
        // The File object
        // The storage path
        const path = `${this.storagePath}/${new Date().getTime()}_${this.tempFile ? this.tempFile.target.files[0].name : '_web'}`;
        // Totally optional metadata
        // The main task
        this.task = this.storage.upload(path, file);
        // Progress monitoring
        this.percentage = this.task.percentageChanges();
        this.snapshot = this.task.snapshotChanges();
        // this.task.snapshotChanges().pipe(
        //   finalize(() => {
        //     storageRef.getDownloadURL().subscribe(downloadURL => {
        //       // fileUpload.url = downloadURL;
        //       // fileUpload.name = fileUpload.file.name;
        //       // this.saveFileData(fileUpload);
        //       this.res.emit({ thumbnail: downloadURL, locationPath: downloadURL.split('/').pop() });
        //     });
        //   })
        // ).subscribe();
        // The file's download URL
        this.task.then(d => {
            d.ref.getDownloadURL().then(url => {
                this.snapshot = undefined;
                this.percentage = undefined;
                this.res.emit({ thumbnail: url, locationPath: d.ref.fullPath.split('/').pop() });
            });
        });
    }
    // Determines if the upload task is active
    isActive(snapshot) {
        return snapshot.state === 'running' && snapshot.bytesTransferred < snapshot.totalBytes;
    }
    ngOnInit() {
        this.texts = new DropZoneText(this.lang);
        if (document.getElementById('dropzone-wrapper').clientWidth < 767) {
            document.getElementById('dropzone-wrapper').classList.add('responsive');
        }
    }
    // CropImageFunctions
    rotateLeft() {
        this.croppedImageConfig.canvasRotation--;
        this.flipAfterRotate();
    }
    rotateRight() {
        this.croppedImageConfig.canvasRotation++;
        this.flipAfterRotate();
    }
    flipAfterRotate() {
        const flippedH = this.croppedImageConfig.transform.flipH;
        const flippedV = this.croppedImageConfig.transform.flipV;
        this.croppedImageConfig.transform = {
            ...this.croppedImageConfig.transform,
            flipH: flippedV,
            flipV: flippedH
        };
    }
    flipHorizontal() {
        this.croppedImageConfig.transform = {
            ...this.croppedImageConfig.transform,
            flipH: !this.croppedImageConfig.transform.flipH
        };
    }
    flipVertical() {
        this.croppedImageConfig.transform = {
            ...this.croppedImageConfig.transform,
            flipV: !this.croppedImageConfig.transform.flipV
        };
    }
    resetImage() {
        this.croppedImageConfig.scale = 1;
        this.croppedImageConfig.transform = {};
        this.croppedImageConfig.rotation = 0;
        this.croppedImageConfig.canvasRotation = 0;
    }
    zoomOut() {
        this.croppedImageConfig.scale -= .1;
        this.croppedImageConfig.transform = {
            ...this.croppedImageConfig.transform,
            scale: this.croppedImageConfig.scale
        };
    }
    zoomIn() {
        this.croppedImageConfig.scale += .1;
        this.croppedImageConfig.transform = {
            ...this.croppedImageConfig.transform,
            scale: this.croppedImageConfig.scale
        };
    }
    imageCropped(event) {
        if (event.objectUrl) {
            this.croppedImage = event.objectUrl;
        }
        else {
            this.croppedImage = event.base64;
        }
    }
    imageLoaded() {
        // console.log('Image loaded');
    }
    cropperReady(sourceImageDimensions) {
        // console.log('Cropper ready', sourceImageDimensions);
    }
    loadImageFailed() {
        console.log('Load failed');
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.1.2", ngImport: i0, type: NgxImageHandlerComponent, deps: [{ token: i1.AngularFireStorage }, { token: i2.DomSanitizer }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "17.1.2", type: NgxImageHandlerComponent, selector: "ngx-image-handler", inputs: { lang: "lang", storagePath: "storagePath", maxSize: "maxSize", imageUrl: "imageUrl", onlyType: "onlyType", cropper: "cropper", cropperConfig: "cropperConfig" }, outputs: { res: "res" }, viewQueries: [{ propertyName: "imageCropper", first: true, predicate: ImageCropperComponent, descendants: true }], ngImport: i0, template: "<div *ngIf=\"error.type || error.size\" class=\"error\" >\n  <span *ngIf=\"error.type\"> {{ texts.errors.type }} </span>\n  <span *ngIf=\"error.size\"> {{ texts.errors.size }} </span>\n</div>\n\n<div class=\"dropzone-wrapper\" id=\"dropzone-wrapper\" >\n\n  <div class=\"dropzone\" dropZone (hovered)=\"toggleHover($event)\" (dropped)=\"loadTempFile($event)\"\n      [class.hovering]=\"isHovering\" *ngIf=\"!tempFile && !imageUrl\" >\n\n    <h3> {{ texts.title }} </h3>\n    <h6> {{ texts.subtitle }} </h6>\n\n    <div class=\"file\">\n      <label class=\"file-label\">\n        <input class=\"file-input\" id=\"file-input\" type=\"file\" (change)=\"loadTempFile($event)\" [hidden]=\"tempFile\">\n        <span class=\"file-cta\">\n          <span class=\"file-icon\">\n            <i class=\"fa fa-upload\"></i>\n          </span>\n          <span class=\"file-label\">\n          {{ texts.action.or }} <strong class=\"click-here\"> {{ texts.action.click }} </strong> {{ texts.action.choose }}\n          </span>\n        </span>\n      </label>\n    </div>\n  </div>\n\n  <div *ngIf=\"tempFile && !ImageType\" style=\"flex: 1;display: flex;justify-content: center;align-items: center;\">\n      {{ tempFile.target.files[0].name }}\n  </div>\n\n  <div *ngIf=\"(tempFile && ImageType) || imageUrl\" class=\"preview-image\" [ngClass]=\"{'disabled': !cropper }\">\n    <image-cropper\n        [imageChangedEvent]=\"tempFile\"\n        [imageURL]=\"imageUrl\"\n        [maintainAspectRatio]=\"cropperConfig.maintainAspectRatio\"\n        [aspectRatio]=\"cropperConfig.aspectRatio\"\n        [disabled]=\"!cropper\"\n        [canvasRotation]=\"croppedImageConfig.canvasRotation\"\n        [transform]=\"croppedImageConfig.transform\"\n        [alignImage]=\"'center'\"\n        [hideResizeSquares]=\"!cropper\"\n        [containWithinAspectRatio]=\"cropperConfig.containWithinAspectRatio\"\n        [resizeToWidth]=\"cropperConfig.resizeToWidth\"\n        [resizeToHeight]=\"cropperConfig.resizeToHeight\"\n        [cropperMinWidth]=\"cropperConfig.cropperMinWidth\"\n        [cropperMinHeight]=\"cropperConfig.cropperMinHeight\"\n        [cropperStaticWidth]=\"cropperConfig.cropperStaticWidth\"\n        [cropperStaticHeight]=\"cropperConfig.cropperStaticHeight\"\n        output='base64'\n        format=\"png\"\n        [autoCrop]=\"true\"\n        (imageCropped)=\"imageCropped($event)\"\n        (imageLoaded)=\"imageLoaded()\"\n        (cropperReady)=\"cropperReady($event)\"\n        (loadImageFailed)=\"loadImageFailed()\"\n    ></image-cropper>\n  </div>\n\n  <div class=\"dropzone-button-wrapper\" *ngIf=\"tempFile || imageUrl \" >\n\n    <div *ngIf=\"(ImageType && cropper) || imageUrl\" class=\"action-wrapper\" >\n      <button type=\"button\" class=\"loader-button half-button\" (click)=\"rotateLeft()\">{{ texts.action.rotateLeft }}</button>\n      <button type=\"button\" class=\"loader-button half-button\" (click)=\"rotateRight()\">{{ texts.action.rotateRight }}</button>\n      <hr>\n      <button type=\"button\" class=\"loader-button half-button\" (click)=\"flipHorizontal()\">{{ texts.action.flipHorizontal }}</button>\n      <button type=\"button\" class=\"loader-button half-button\" (click)=\"flipVertical()\"> {{ texts.action.flipVertical }}</button>\n      <hr>\n\n      <button type=\"button\" class=\"loader-button half-button\" (click)=\"zoomOut()\">{{ texts.action.zoomOut }}</button>\n      <button type=\"button\" class=\"loader-button half-button\" (click)=\"zoomIn()\">{{ texts.action.zoomIn }}</button>\n      <hr>\n\n      <button type=\"button\" class=\"loader-button half-button\" (click)=\"resetImage()\">{{ texts.action.reset }}</button>\n      <hr>\n    </div>\n\n    <button type=\"button\" class=\"loader-button button--warning\"  (click)=\"changeImage()\" > {{ texts.button.change }} </button>\n    <button type=\"button\" class=\"loader-button button--success\"  (click)=\"startUpload()\" > {{ texts.button.upload }} </button>\n\n    <div>\n\n    <div *ngIf=\"(percentage | async) as pct\">\n      <progress class=\"progress is-info\" [value]=\"pct || 0\" max=\"100\">\n      </progress>\n      {{ pct | number }}%\n    </div>\n\n    <div *ngIf=\"(snapshot | async) as snap\">\n      {{ snap.bytesTransferred | fileSize }} of {{ snap.totalBytes | fileSize }}\n      <button type=\"button\" (click)=\"task?.pause()\" class=\"button is-warning\" [disabled]=\"!isActive(snap)\">{{ texts.button.pause }}</button>\n      <button type=\"button\" (click)=\"task?.cancel()\" class=\"button is-danger\" [disabled]=\"!isActive(snap)\">{{ texts.button.cancel }}</button>\n      <button type=\"button\" (click)=\"task?.resume()\" class=\"button is-info\" [disabled]=\"!(snap?.state === 'paused')\">{{ texts.button.resume }}</button>\n    </div>\n\n    </div>\n  </div>\n\n</div>\n", styles: ["*{font-family:\"sans-serif\"}::ng-deep .preview-image.disabled div.ngx-ic-cropper{visibility:hidden!important}button:focus{outline:none}image-cropper{min-height:100px}.dropzone-wrapper{display:flex;flex-wrap:wrap}strong.click-here{cursor:pointer}.preview-image{flex:1 0;min-height:100px;max-height:500px;padding:.5rem}.dropzone-button-wrapper{flex:.2 0 100px;box-sizing:border-box;padding:.5rem 1rem;flex-wrap:wrap;display:flex;max-height:350px}.file-label{pointer-events:none}.dropzone{flex:1;display:flex;align-items:center;justify-content:center;flex-direction:column;height:100%;min-height:100px;border:2px dashed #f16624;border-radius:5px;background:#fff;margin:0;cursor:pointer;padding:.5rem;font-family:\"sans-serif\"}.dropzone:hover{border:2px solid #f16624;color:#dadada!important}.dropzone .file input.file-input{width:0}progress::-webkit-progress-value{transition:width .1s ease}.action-wrapper{flex:1 0 100%}.loader-button{flex:1 0 150px;padding:.5rem .4rem;margin-bottom:8px;border:none;font-size:12px;font-family:sans-serif;border-radius:.5rem;cursor:pointer;transition:.3s;height:2rem}.half-button{width:49%}.half-button+.half-button{margin-left:2%}.loader-button:hover{filter:brightness(.8)}.loader-button.button--success{background:#4145c7;color:#fff;flex:1 0 60%}.loader-button.button--warning{background:#ea782600;color:#ea7826;flex:1 0 auto;min-width:100px}.error{font-family:\"sans-serif\";color:#d63600;font-weight:700;letter-spacing:-1px}@media (max-width: 767px){.dropzone-button-wrapper{flex:1 0 100%;box-shadow:none}}.dropzone-wrapper.responsive .dropzone-button-wrapper{flex:1 0 100%;box-shadow:none}\n"], dependencies: [{ kind: "directive", type: i3.NgClass, selector: "[ngClass]", inputs: ["class", "ngClass"] }, { kind: "directive", type: i3.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "component", type: i4.ImageCropperComponent, selector: "image-cropper", inputs: ["imageChangedEvent", "imageURL", "imageBase64", "imageFile", "imageAltText", "cropperFrameAriaLabel", "output", "format", "transform", "maintainAspectRatio", "aspectRatio", "resetCropOnAspectRatioChange", "resizeToWidth", "resizeToHeight", "cropperMinWidth", "cropperMinHeight", "cropperMaxHeight", "cropperMaxWidth", "cropperStaticWidth", "cropperStaticHeight", "canvasRotation", "initialStepSize", "roundCropper", "onlyScaleDown", "imageQuality", "autoCrop", "backgroundColor", "containWithinAspectRatio", "hideResizeSquares", "allowMoveImage", "cropper", "alignImage", "disabled", "hidden"], outputs: ["imageCropped", "startCropImage", "imageLoaded", "cropperReady", "loadImageFailed", "transformChange"] }, { kind: "directive", type: DropZoneDirective, selector: "[dropZone]", outputs: ["dropped", "hovered"] }, { kind: "pipe", type: i3.AsyncPipe, name: "async" }, { kind: "pipe", type: i3.DecimalPipe, name: "number" }, { kind: "pipe", type: FileSizePipe, name: "fileSize" }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.1.2", ngImport: i0, type: NgxImageHandlerComponent, decorators: [{
            type: Component,
            args: [{ selector: 'ngx-image-handler', template: "<div *ngIf=\"error.type || error.size\" class=\"error\" >\n  <span *ngIf=\"error.type\"> {{ texts.errors.type }} </span>\n  <span *ngIf=\"error.size\"> {{ texts.errors.size }} </span>\n</div>\n\n<div class=\"dropzone-wrapper\" id=\"dropzone-wrapper\" >\n\n  <div class=\"dropzone\" dropZone (hovered)=\"toggleHover($event)\" (dropped)=\"loadTempFile($event)\"\n      [class.hovering]=\"isHovering\" *ngIf=\"!tempFile && !imageUrl\" >\n\n    <h3> {{ texts.title }} </h3>\n    <h6> {{ texts.subtitle }} </h6>\n\n    <div class=\"file\">\n      <label class=\"file-label\">\n        <input class=\"file-input\" id=\"file-input\" type=\"file\" (change)=\"loadTempFile($event)\" [hidden]=\"tempFile\">\n        <span class=\"file-cta\">\n          <span class=\"file-icon\">\n            <i class=\"fa fa-upload\"></i>\n          </span>\n          <span class=\"file-label\">\n          {{ texts.action.or }} <strong class=\"click-here\"> {{ texts.action.click }} </strong> {{ texts.action.choose }}\n          </span>\n        </span>\n      </label>\n    </div>\n  </div>\n\n  <div *ngIf=\"tempFile && !ImageType\" style=\"flex: 1;display: flex;justify-content: center;align-items: center;\">\n      {{ tempFile.target.files[0].name }}\n  </div>\n\n  <div *ngIf=\"(tempFile && ImageType) || imageUrl\" class=\"preview-image\" [ngClass]=\"{'disabled': !cropper }\">\n    <image-cropper\n        [imageChangedEvent]=\"tempFile\"\n        [imageURL]=\"imageUrl\"\n        [maintainAspectRatio]=\"cropperConfig.maintainAspectRatio\"\n        [aspectRatio]=\"cropperConfig.aspectRatio\"\n        [disabled]=\"!cropper\"\n        [canvasRotation]=\"croppedImageConfig.canvasRotation\"\n        [transform]=\"croppedImageConfig.transform\"\n        [alignImage]=\"'center'\"\n        [hideResizeSquares]=\"!cropper\"\n        [containWithinAspectRatio]=\"cropperConfig.containWithinAspectRatio\"\n        [resizeToWidth]=\"cropperConfig.resizeToWidth\"\n        [resizeToHeight]=\"cropperConfig.resizeToHeight\"\n        [cropperMinWidth]=\"cropperConfig.cropperMinWidth\"\n        [cropperMinHeight]=\"cropperConfig.cropperMinHeight\"\n        [cropperStaticWidth]=\"cropperConfig.cropperStaticWidth\"\n        [cropperStaticHeight]=\"cropperConfig.cropperStaticHeight\"\n        output='base64'\n        format=\"png\"\n        [autoCrop]=\"true\"\n        (imageCropped)=\"imageCropped($event)\"\n        (imageLoaded)=\"imageLoaded()\"\n        (cropperReady)=\"cropperReady($event)\"\n        (loadImageFailed)=\"loadImageFailed()\"\n    ></image-cropper>\n  </div>\n\n  <div class=\"dropzone-button-wrapper\" *ngIf=\"tempFile || imageUrl \" >\n\n    <div *ngIf=\"(ImageType && cropper) || imageUrl\" class=\"action-wrapper\" >\n      <button type=\"button\" class=\"loader-button half-button\" (click)=\"rotateLeft()\">{{ texts.action.rotateLeft }}</button>\n      <button type=\"button\" class=\"loader-button half-button\" (click)=\"rotateRight()\">{{ texts.action.rotateRight }}</button>\n      <hr>\n      <button type=\"button\" class=\"loader-button half-button\" (click)=\"flipHorizontal()\">{{ texts.action.flipHorizontal }}</button>\n      <button type=\"button\" class=\"loader-button half-button\" (click)=\"flipVertical()\"> {{ texts.action.flipVertical }}</button>\n      <hr>\n\n      <button type=\"button\" class=\"loader-button half-button\" (click)=\"zoomOut()\">{{ texts.action.zoomOut }}</button>\n      <button type=\"button\" class=\"loader-button half-button\" (click)=\"zoomIn()\">{{ texts.action.zoomIn }}</button>\n      <hr>\n\n      <button type=\"button\" class=\"loader-button half-button\" (click)=\"resetImage()\">{{ texts.action.reset }}</button>\n      <hr>\n    </div>\n\n    <button type=\"button\" class=\"loader-button button--warning\"  (click)=\"changeImage()\" > {{ texts.button.change }} </button>\n    <button type=\"button\" class=\"loader-button button--success\"  (click)=\"startUpload()\" > {{ texts.button.upload }} </button>\n\n    <div>\n\n    <div *ngIf=\"(percentage | async) as pct\">\n      <progress class=\"progress is-info\" [value]=\"pct || 0\" max=\"100\">\n      </progress>\n      {{ pct | number }}%\n    </div>\n\n    <div *ngIf=\"(snapshot | async) as snap\">\n      {{ snap.bytesTransferred | fileSize }} of {{ snap.totalBytes | fileSize }}\n      <button type=\"button\" (click)=\"task?.pause()\" class=\"button is-warning\" [disabled]=\"!isActive(snap)\">{{ texts.button.pause }}</button>\n      <button type=\"button\" (click)=\"task?.cancel()\" class=\"button is-danger\" [disabled]=\"!isActive(snap)\">{{ texts.button.cancel }}</button>\n      <button type=\"button\" (click)=\"task?.resume()\" class=\"button is-info\" [disabled]=\"!(snap?.state === 'paused')\">{{ texts.button.resume }}</button>\n    </div>\n\n    </div>\n  </div>\n\n</div>\n", styles: ["*{font-family:\"sans-serif\"}::ng-deep .preview-image.disabled div.ngx-ic-cropper{visibility:hidden!important}button:focus{outline:none}image-cropper{min-height:100px}.dropzone-wrapper{display:flex;flex-wrap:wrap}strong.click-here{cursor:pointer}.preview-image{flex:1 0;min-height:100px;max-height:500px;padding:.5rem}.dropzone-button-wrapper{flex:.2 0 100px;box-sizing:border-box;padding:.5rem 1rem;flex-wrap:wrap;display:flex;max-height:350px}.file-label{pointer-events:none}.dropzone{flex:1;display:flex;align-items:center;justify-content:center;flex-direction:column;height:100%;min-height:100px;border:2px dashed #f16624;border-radius:5px;background:#fff;margin:0;cursor:pointer;padding:.5rem;font-family:\"sans-serif\"}.dropzone:hover{border:2px solid #f16624;color:#dadada!important}.dropzone .file input.file-input{width:0}progress::-webkit-progress-value{transition:width .1s ease}.action-wrapper{flex:1 0 100%}.loader-button{flex:1 0 150px;padding:.5rem .4rem;margin-bottom:8px;border:none;font-size:12px;font-family:sans-serif;border-radius:.5rem;cursor:pointer;transition:.3s;height:2rem}.half-button{width:49%}.half-button+.half-button{margin-left:2%}.loader-button:hover{filter:brightness(.8)}.loader-button.button--success{background:#4145c7;color:#fff;flex:1 0 60%}.loader-button.button--warning{background:#ea782600;color:#ea7826;flex:1 0 auto;min-width:100px}.error{font-family:\"sans-serif\";color:#d63600;font-weight:700;letter-spacing:-1px}@media (max-width: 767px){.dropzone-button-wrapper{flex:1 0 100%;box-shadow:none}}.dropzone-wrapper.responsive .dropzone-button-wrapper{flex:1 0 100%;box-shadow:none}\n"] }]
        }], ctorParameters: () => [{ type: i1.AngularFireStorage }, { type: i2.DomSanitizer }], propDecorators: { imageCropper: [{
                type: ViewChild,
                args: [ImageCropperComponent]
            }], res: [{
                type: Output
            }], lang: [{
                type: Input
            }], storagePath: [{
                type: Input
            }], maxSize: [{
                type: Input
            }], imageUrl: [{
                type: Input
            }], onlyType: [{
                type: Input
            }], cropper: [{
                type: Input
            }], cropperConfig: [{
                type: Input
            }] } });

const COMPONENTS = [
    NgxImageHandlerComponent,
    FileSizePipe,
    DropZoneDirective,
];
class NgxImageHandlerModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.1.2", ngImport: i0, type: NgxImageHandlerModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "17.1.2", ngImport: i0, type: NgxImageHandlerModule, declarations: [NgxImageHandlerComponent,
            FileSizePipe,
            DropZoneDirective], imports: [CommonModule,
            ImageCropperModule], exports: [NgxImageHandlerComponent,
            FileSizePipe,
            DropZoneDirective] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "17.1.2", ngImport: i0, type: NgxImageHandlerModule, imports: [CommonModule,
            ImageCropperModule] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.1.2", ngImport: i0, type: NgxImageHandlerModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [...COMPONENTS],
                    imports: [
                        CommonModule,
                        ImageCropperModule
                    ],
                    exports: [...COMPONENTS],
                }]
        }] });

class NgxImageHandlerService {
    constructor() { }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.1.2", ngImport: i0, type: NgxImageHandlerService, deps: [], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "17.1.2", ngImport: i0, type: NgxImageHandlerService, providedIn: 'root' }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.1.2", ngImport: i0, type: NgxImageHandlerService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], ctorParameters: () => [] });

/*
 * Public API Surface of ngx-image-handler
 */

/**
 * Generated bundle index. Do not edit.
 */

export { DropZoneDirective, FileSizePipe, NgxImageHandlerComponent, NgxImageHandlerModule, NgxImageHandlerService };
//# sourceMappingURL=ngx-image-handler.mjs.map
